<div align="center">
  <h1>drive-events</h1>
  <p><strong>Build event-driven applications with python functions</strong></p>
  <p>
    <img src="https://img.shields.io/badge/python->=3.9.11-blue">
    <a href="https://pypi.org/project/drive-events/">
      <img src="https://img.shields.io/pypi/v/drive-events.svg">
    </a>
  </p>
</div>




## Install

**Install from PyPi**

```shell
pip install drive-events
```

**Install from source**

```shell
# clone this repo first
cd drive-events
pip install -e .
```

## Quick Start

TODO
